@@ -3,7 +3,6 @@ package DBIx::EAV;
 use Moo;
 use strictures 2;
 use DBI;
-use DateTime;
 use Lingua::EN::Inflect ();
 use Data::Dumper;
 use DBIx::EAV::EntityType;
@@ -13,12 +12,13 @@ use DBIx::EAV::Schema;
 use Carp qw/croak confess/;
 use Scalar::Util 'blessed';
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 # required
 has 'dbh', is => 'ro', required => 1;
 
 # options
+has 'default_attribute_type', is => 'ro', default => 'varchar';
 has 'schema_config', is => 'ro', default => sub { {} };
 
 # internal
@@ -34,7 +34,7 @@ around BUILDARGS => sub {
 
     my @schema_params = grep { exists $params->{$_} } qw/
         tenant_id         data_types   database_cascade_delete static_attributes
-        table_prefix      id_type      default_data_type
+        table_prefix      id_type      default_attribute_type
     /;
 
     @{$schema_config}{@schema_params} = delete @{$params}{@schema_params};
@@ -194,7 +194,7 @@ sub _register_entity {
             my ($name, $type) = split ':', $attr_spec;
             $attr_spec = {
                 name => $name,
-                type => $type || $self->schema->default_data_type
+                type => $type || $self->default_attribute_type
             };
         }
 
@@ -218,7 +218,7 @@ sub _register_entity {
             my %data = %$attr_spec;
 
             $data{entity_type_id} = $type->{id};
-            $data{data_type} = delete($data{type}) || $self->schema->default_data_type;
+            $data{data_type} = delete($data{type}) || $self->default_attribute_type;
 
             die sprintf("Attribute '%s' has unknown data type '%s'.", $data{name}, $data{data_type})
                 unless $self->schema->has_data_type($data{data_type});
@@ -363,89 +363,6 @@ other developers try it, and help identify any major design flaw before we can
 stabilize the API. One exception is the ResultSet whose API (and docs :]) I've
 borrowed from L<DBIx::Class>, so its (API is) already stable.
 
-=head1 WHAT'S EAV?
-
-EAV is a data model where instead of representing each entity using a physical
-table with columns representing its attributes, everything is stored as rows of
-the eav tables. Each entity is stored as a row of the 'entities' table, and each
-of its attributes values are stored as a row of one of the values table. There is
-one value table for each data type.
-
-For a better explanation of what an Entity-Attribute-Value data model is, check Wikipedia.
-The specific tables used by this implementation are described in L<DBIx::EAV::Schema>.
-
-=head1 EAV USE CASES
-
-=head2 When the number of possible attributes is huge
-
-EAV modeling has been used by health and clinical software by decades because the
-number of possible attributes like tests results and diagnostics are huge and
-just a few of those attributes are acctualy filled (non-NULL).
-
-=head2 When you dont't know your schema in advance
-
-E-commerce solutions use EAV modeling to allow the definition of any kind of product
-and still be able to do filtering/sorting of results based of product attributes.
-For example, the entity 'HardDrive' would have atrributes 'capacity' and 'rpm',
-while entity 'Monitor' would have attributes 'resolution' and 'contrast_ratio'.
-
-=head2 To abstract the physical database layer
-
-Many SaaS platforms use EAV modeling to offer database services to its custormers,
-without exposing the physical database system.
-
-=head2 When you need frequent changes to your schema
-
-An open-schema data model can be useful for app prototyping.
-
-=head1 DBIx::EAV CONCEPTS
-
-=head2 EntityType
-
-An L<EntityType|DBIx::EAV::EntityType> is the blueprint of an entity. Like a
-Class in OOP. Each type has  a unique name, one or more attributes and zero or
-more relationships. See L<DBIx::EAV::EntityType>.
-
-=head2 Entity
-
-An actual entity record (of some type) that has its own id and attribute values.
-See L<DBIx::EAV::Entity>.
-
-=head2 Attribute
-
-Attributes are analogous to columns in traditional database modeling. Its the
-actual named properties that describes an entity type. Every attribute has a
-unique name and a data type. Unlike traditional table columns, adding/removing
-attributes to an existing entity type is very easy and cheap.
-
-=head2 Value
-
-The actual attribute data stored in one of the value tables. There is one value
-table for each data type.
-See L</data_types>, L<DBIx::EAV::Schema>.
-
-=head2 Physical Schema
-
-This is the actual database tables used by the EAV system. Its represented by
-L<DBIx::EAV::Schema>.
-
-=head2 EAV Schema
-
-Its the total set of Entity Types registered on the system, which form the
-actual application business model.
-See L</register_types>.
-
-=head2 ResultSet
-
-Concept borrowed from L<DBIx::Class>, a ResultSet represents a query used for
-fetching a set of entities of a type, as well as other CRUD operations on
-multiple entities.
-
-=head2 Cursor
-
-A Cursor is used internally by the ResultSet to prepare, execute and traverse
-through SELECT queries.
-
 =head1 CONSTRUCTORS
 
 =head2 new
@@ -569,24 +486,6 @@ C<STDERR>.
 
 =back
 
-=head1 CASCADE DELETE
-
-Since a single L<entity|DBIx::EAV::Entity>'s data is spread over several value
-tables, we can't just delete the entity in a single SQL C<DELETE> command.
-We must first send a C<DELETE> for each of those value tables, and one more for
-the L<entity_relationships|DBIx::EAV::Schema/entity_relationships> table. If an
-entity has attributes of 4 data types, and has any relationship defined, a total
-of 6 (six!!) C<DELETE> commands will be needed to delete a single entity. Four
-to the value tables, one for the entity_relationships and one for the actual
-entities table).
-
-Those extra C<DELETE> commands can be avoided by using database-level
-C<ON DELETE CASCADE> for the references from the B<values> and
-B<entity_relationships> tables to the B<entities> table.
-
-If those contraints are in place, set L<database_cascade_delete|new> to C<1> and
-those extra C<DELETE> commands will not be sent.
-
 =head1 LICENSE
 
 Copyright (C) Carlos Fernando Avila Gratz.
